#
# spec file for package proxychains-ng
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           proxychains-ng
Version:        4.17
Release:        1.2
Summary:        Redirect connection through proxy servers
License:        GPL-2.0-only
Group:          Productivity/Networking/Security
URL:            https://github.com/rofl0r/proxychains-ng
Source0:        https://ftp.barfooze.de/pub/sabotage/tarballs/proxychains-ng-%{version}.tar.xz
Source1:        %{name}-rpmlintrc
BuildRequires:  make
Obsoletes:      proxychains < %{version}
Provides:       proxychains = %{version}

%description
ProxyChains NG is based on ProxyChains.

ProxyChains NG hooks network-related (TCP only) libc functions in dynamically
linked programs via a preloaded DSO (dynamic shared object) and redirects the
connections through one or more SOCKS4a/5 or HTTP proxies.

Since Proxy Chains NG relies on the dynamic linker, statically linked binaries
are not supported.

Adjust ~/.proxychains/proxychains.conf for your Proxy and use ProxyChains NG
with

    proxychains4 application

%prep
%setup -q

%build
%configure
%make_build

%install
%make_install install-config
install -Dm 0755 src/proxyresolv %{buildroot}%{_bindir}/proxyresolv4

%files
%doc AUTHORS README TODO
%license COPYING
%{_bindir}/proxychains4
%{_bindir}/proxychains4-daemon
%{_bindir}/proxyresolv4
%{_libdir}/libproxychains4.so
%config %{_sysconfdir}/proxychains.conf

%changelog
* Sun Apr  7 2024 Martin Hauke <mardnh@gmx.de>
- Update to version 4.17:
  * add hook for close_range function, fixing newer versions of
    openssh
  * fix DNS error handling in proxy_dns_old
  * simplify init code
  * fix double-close in multithreaded apps
  * various improvements to configure script
- Drop %%check section
  * nothing useful was done there
* Wed May  4 2022 Martin Hauke <mardnh@gmx.de>
- Update to version 4.16:
  * fix regression in configure script linker flag detection
  * remove 10 year old workaround for wrong glibc getnameinfo
    signature
  * support IPv6 localnets
  * more user-friendly error message when execvp fails
  * proxy_getaddrinfo(): fill in ai_socktype if requested
- Update to version 4.15:
  * fix configure script for buggy binutils version
  * initialize rand_seed with nano-second granularity
  * add support for numeric ipv6 in getaddrinfo
  * fix bug in getaddrinfo when node is null and !passive
  * add dnat feature
  * add raw proxy type
  * add proxy_dns_old to emulate proxychains 3.1 behaviour
  * add new proxy_dns_daemon feature (experimental)
  * various other fixes
* Fri Jan 22 2021 Dirk Müller <dmueller@suse.com>
- update to to 4.14:
  - allow alternative proto://user:pass@ip:port syntax for proxylist
  - fix endless loop in round robin mode when all proxies are down (#147)
  - fix compilation on android (#265)
  - fix fd leak in forked processes (#273)
  - skip connection attempt to nullrouted ips
  - allow hostnames for proxylist under specific circumstances
  - fix robustness of DNS lookup thread and a segfault
  - fix socks5 user/pass auth on non-conforming servers
  - fix memory leak
  - add support for Solaris
  - fix several build issues
  - for MAC
  - with -pie
  - with custom CC
  - compatibility fix for some GUI apps (8870140)
  - compatibility fix for some HTTP proxies (cf9a16d)
  - fix several warnings for cleaner build on debian
  - fix random_chain on OSX (0f6b226)
* Wed Feb 10 2016 nemysis@openSUSE.org
- Update to 4.11, announce message:
  - preliminary IPv6 support
  - fixed bug in hostsreader
  - preliminary support for usage on OpenBSD (caveat emptor)
* Wed Jun 10 2015 nemysis@gmx.ch
- Update to 4.10, announce message:
  - fix regression in linking order with custom LDFLAGS
  - fix segfault in DNS mapping code in programs with > ~400 different lookups
- Adjust proxychains-ng-rpmlintrc, after conversation with Upstream
* Thu May 28 2015 nemysis@gmx.ch
- Update to 4.9, announce message:
  - fix a security issue CVE-2015-3887
  - add sendto hook to handle MSG_FASTOPEN flag
  - replace problematic hostentdb with hostsreader
  - fix compilation on OpenBSD (although doesn't work there)
* Wed Oct 15 2014 nemysis@gmx.ch
- Change Group from Productivity/Networking to
  Productivity/Networking/Security
- Fix typo
* Mon Oct 13 2014 nemysis@gmx.ch
- Add Source1 proxychains-ng-rpmlintrc
- Use install-config instead of install
- Use +%%config %%{_sysconfdir} instead of %%{_sysconfdir}
* Sun Sep 14 2014 nemysis@gmx.ch
- Change Url from GitHub to SourceForge
- Change Source to use Web Url
* Sat Sep 13 2014 nemysis@gmx.ch
- Add Obsoletes and Provides for conflict with Proxy Chains
- Use %%setup -q -n proxychains-%%{version} and remove not needed Source
- Add proxychains.conf, forgotten in previous commit
* Sat Sep 13 2014 nemysis@gmx.ch
- Use for Group Productivity/Networking instead of Network
- Remove all define and #setup -n because not works
- Use proxyresolv4 instead proxyresolv to not have conflict with
  Proxy Chains 3.1
- Add proxychains-ng-rpmlintrc, thanks va from IRC
* Sat Sep 13 2014 nemysis@gmx.ch
- Initial package creation
- Problem with package name, because this have added two tar.bz2
  define and setup -n not helps
